@@ -2,10 +2,12 @@
 package Module::CPANfile::Environment;
 use strict;
 use Module::CPANfile::Result;
+use Carp ();
 
 my @bindings = qw(
     on requires recommends suggests conflicts
-    osname perl
+    feature
+    osname
     configure_requires build_requires test_requires author_requires
 );
 
@@ -36,10 +38,11 @@ sub parse {
         local $@;
         $res = eval sprintf <<EVAL, $file_id++;
 package Module::CPANfile::Sandbox%d;
-my \$_result;
 no warnings;
-use Module::CPANfile::Environment \\\$_result;
+my \$_result;
+BEGIN { import Module::CPANfile::Environment \\\$_result };
 
+# line 1 "$file"
 $code;
 
 \$_result;
@@ -53,3 +56,4 @@ EVAL
 }
 
 1;
+
